"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tap_1 = require("tap");
const create_ffmpeg_options_1 = require("../create-ffmpeg-options");
const default_ffmpeg_options_1 = require("../default-ffmpeg-options");
tap_1.test('invalid timestamp', function (t) {
    t.plan(1);
    try {
        create_ffmpeg_options_1.createFFmpegOptions('video.mov', 'build', {
            ...default_ffmpeg_options_1.defaultFFmpegOptions,
            trim: 'foo'
        });
        t.fail();
    }
    catch {
        t.pass();
    }
});
tap_1.test('start timestamp only', function (t) {
    t.plan(2);
    const { flags, outputFile } = create_ffmpeg_options_1.createFFmpegOptions('video.mov', 'build', {
        ...default_ffmpeg_options_1.defaultFFmpegOptions,
        trim: '0:05'
    });
    t.deepEqual({
        'an': null,
        'codec:a': 'copy',
        'codec:v': 'copy',
        'filter:a': [],
        'filter:v': [],
        'i': 'video.mov',
        'ss': '0:05',
        'to': null
    }, flags);
    t.equal(outputFile, 'build/video.mov');
});
tap_1.test('invalid start timestamp', function (t) {
    t.plan(1);
    try {
        create_ffmpeg_options_1.createFFmpegOptions('video.mov', 'build', {
            ...default_ffmpeg_options_1.defaultFFmpegOptions,
            trim: 'foo,0:10'
        });
        t.fail();
    }
    catch {
        t.pass();
    }
});
tap_1.test('invalid end timestamp', function (t) {
    t.plan(1);
    try {
        create_ffmpeg_options_1.createFFmpegOptions('video.mov', 'build', {
            ...default_ffmpeg_options_1.defaultFFmpegOptions,
            trim: '0:05,foo'
        });
        t.fail();
    }
    catch {
        t.pass();
    }
});
tap_1.test('start and end timestamp', function (t) {
    t.plan(2);
    const { flags, outputFile } = create_ffmpeg_options_1.createFFmpegOptions('video.mov', 'build', {
        ...default_ffmpeg_options_1.defaultFFmpegOptions,
        trim: '0:05,0:10'
    });
    t.deepEqual({
        'an': null,
        'codec:a': 'copy',
        'codec:v': 'copy',
        'filter:a': [],
        'filter:v': [],
        'i': 'video.mov',
        'ss': '0:05',
        'to': '0:10'
    }, flags);
    t.equal(outputFile, 'build/video.mov');
});
