"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFFmpegShellCommands = void 0;
const globby = require("globby");
const which = require("which");
const create_ffmpeg_options_1 = require("./create-ffmpeg-options/create-ffmpeg-options");
async function createFFmpegShellCommands(globPatterns, outputDirectory, vdxOptions) {
    const ffmpegBinaryPath = await which('ffmpeg');
    const inputFiles = await globby(globPatterns);
    const result = [];
    for (const inputFile of inputFiles) {
        const { flags, outputFile } = create_ffmpeg_options_1.createFFmpegOptions(inputFile, outputDirectory, vdxOptions);
        result.push({
            inputFile,
            outputFile,
            shellCommand: createFFmpegShellCommand(ffmpegBinaryPath, flags, outputFile)
        });
    }
    return result;
}
exports.createFFmpegShellCommands = createFFmpegShellCommands;
function createFFmpegShellCommand(ffmpegBinaryPath, ffmpegFlags, outputFile) {
    const result = [];
    if (ffmpegFlags.ss !== null) {
        result.push(`-ss ${ffmpegFlags.ss}`);
    }
    if (ffmpegFlags.to !== null) {
        result.push(`-to ${ffmpegFlags.to}`);
    }
    result.push(`-i ${ffmpegFlags.i}`);
    if (ffmpegFlags.an === true) {
        result.push(`-an`);
    }
    if (ffmpegFlags['codec:a'] !== null) {
        result.push(`-codec:a ${ffmpegFlags['codec:a']}`);
    }
    if (ffmpegFlags['codec:v'] !== null) {
        result.push(`-codec:v ${ffmpegFlags['codec:v']}`);
    }
    if (ffmpegFlags['filter:a'] !== null && ffmpegFlags['filter:a'].length > 0) {
        result.push(`-filter:a "${ffmpegFlags['filter:a'].slice().sort().join(',')}"`);
    }
    if (ffmpegFlags['filter:v'] !== null && ffmpegFlags['filter:v'].length > 0) {
        result.push(`-filter:v "${ffmpegFlags['filter:v'].slice().sort().join(',')}"`);
    }
    return `${ffmpegBinaryPath} ${result.join(' ')} -y ${outputFile}`;
}
